pilas.evento

Package pilas :: Module evento |
[hide private]
[frames] | no frames]

# Module evento

source code

# Módulo pilas.evento

Classes | [hide private]
| Evento
| AttrDict Envoltorio para que el diccionario de eventos se pueda acceder usando como si tuviera attributos de objeto.
| ProxyFuncion Representa a una función de repuesta pero usando una referencia débil.
| ProxyMetodo Permite asociar funciones pero con referencias débiles, que no incrementan el contador de referencias.
| ProxyEventos Representa el objeto pilas.evento, que internamente delega todos los metodos conectados a la escena actual.

Variables | [hide private]
| __doc__ = ``...``
| __package__ = ``'``pilas``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      M\xc3\xb3dulo pilas.evento
      ===================

      """